@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -19,9 +19,9 @@
 */
 
 #include "inserttablewidget.h"
+#include "kpimtextedit_debug.h"
 #include <KLocalizedString>
 #include <KComboBox>
-#include <QDebug>
 
 #include <QSpinBox>
 #include <QLabel>
@@ -105,7 +105,7 @@ void InsertTableWidget::slotTypeOfLengthChanged(int index)
         d->mLength->setMaximum(9999);
         break;
     default:
-        qDebug() << " index not defined " << index;
+        qCDebug(KPIMTEXTEDIT_LOG) << " index not defined " << index;
         break;
     }
 }
